==> ktorrent-2.0.2.tar.bz2: ktorrent-2.0.2/plugins/infowidget/infowidgetplugin.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTINFOWIDGETPLUGIN_H
#define KTINFOWIDGETPLUGIN_H

#include <interfaces/plugin.h>
#include <interfaces/guiinterface.h>



namespace kt
{
	class InfoWidget;
	class InfoWidgetPrefPage;

	/**
	@author Joris Guisson
	*/
	class InfoWidgetPlugin : public Plugin,public ViewListener
	{
		Q_OBJECT
	public:
		InfoWidgetPlugin(QObject* parent, const char* name, const QStringList& args);
		virtual ~InfoWidgetPlugin();

		virtual void load();
		virtual void unload();
		virtual void guiUpdate();
		virtual void currentDownloadChanged(TorrentInterface* tc);
		virtual void currentSeedChanged(TorrentInterface* tc);
		
	private:
		InfoWidget* iw;
		InfoWidget* iw_seed;
		InfoWidgetPrefPage* pref;
	};

}

#endif

==> ktorrent-2.1.3.tar.bz2: ktorrent-2.1.3/plugins/infowidget/infowidgetplugin.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTINFOWIDGETPLUGIN_H
#define KTINFOWIDGETPLUGIN_H

#include <interfaces/plugin.h>
#include <interfaces/guiinterface.h>



namespace kt
{
	class InfoWidget;
	class InfoWidgetPrefPage;

	/**
	@author Joris Guisson
	*/
	class InfoWidgetPlugin : public Plugin,public ViewListener
	{
		Q_OBJECT
	public:
		InfoWidgetPlugin(QObject* parent, const char* name, const QStringList& args);
		virtual ~InfoWidgetPlugin();

		virtual void load();
		virtual void unload();
		virtual void guiUpdate();
		virtual void currentTorrentChanged(TorrentInterface* tc);
		virtual bool versionCheck(const QString & version) const;
		
	private:
		InfoWidget* iw;
		InfoWidgetPrefPage* pref;
	};

}

#endif
